#define STATUS_K	'K'
#define BYTE		unsigned char
#define TRUE	1
#define FALSE	0

struct DirMesStruct
{
	char		cType;		/* Message type */
	char		cStatus; 	/* Message status */
	unsigned long   dwNumber;	/* Message number */
	char		szDate[12];	/* Message date */
	BYTE		byTi_Hour;	/* Message time (minutes) */
	BYTE		byTi_Min;	/* Message time (hours) */
	char		szRecipient[7];	/* Addresses */
	char		szRoute[10];	/* Routage (@) (call+ssid) */
	char		szSender[7];	/* Sender */
	char		szTitle[61];	/* Message title */
	char		szStartNode[10];/* From Cluster */
	char		szBid[13];	/* BID */
	char		szRcvNode[10];	/* Ajdacent cluster which fwd this mail */
	BYTE		byNoAutoDelete;	/* TRUE : do not delete */
	char		szReserved[100];/* Reserved */
};
